bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.plot
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.plot